Event class base

Base class for all events in the system.

All events should extend this class to ensure proper type safety and event handling throughout the application.

Example:

class UserCreatedEvent extends Event {
  final String userId;
  final String username;

  UserCreatedEvent(this.userId, this.username);
}
Implementers

Constructors

Event()
Creates a new event with the current timestamp.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp when the event was created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited