Event class base
Base class for all events in the system.
All events should extend this class to ensure proper type safety and event handling throughout the application.
Example:
class UserCreatedEvent extends Event {
final String userId;
final String username;
UserCreatedEvent(this.userId, this.username);
}
- Implementers
- AfterRoutingEvent
- BeforeRoutingEvent
- BindingRegisteredEvent
- InstanceResolvedEvent
- ProviderBootedEvent
- ProviderRegisteredEvent
- RequestContainerCreatedEvent
- RequestContainerDisposedEvent
- RequestFinishedEvent
- RequestStartedEvent
- RouteCacheInvalidatedEvent
- RouteMatchedEvent
- RouteNotFoundEvent
- RoutingErrorEvent
- SystemErrorEvent
- UnhandledSignalError
Constructors
- Event()
- Creates a new event with the current timestamp.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited